==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sv.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokument",
    "Can't create document" : "Kan inte skapa dokument",
    "You don't have permission to rename this document" : "Du har inte behörighet att döpa om detta dokument",
    "Directory saved successfully." : "Katalog sparades.",
    "An error occurred while changing directory." : "Ett fel uppstod vid byte av katalog",
    "Saved" : "Sparad",
    "Format filter server is down or misconfigured" : "Formatfilter servern är ur funktion eller felkonfigurerad",
    "Conversion failed. Check log for details." : "Konvertering misslyckades. Se loggen för detaljer.",
    "Saving..." : "Sparar...",
    "Failed to load documents." : "Kunde inte ladda dokumenten.",
    "No documents were found. Upload or create a document to get started!" : "Inga dokument hittades. Ladda upp eller skapa ett dokument för att komma igång!",
    "No connection to server. Trying to reconnect." : "Ingen kontakt med servern. Försöker att koppla upp igen.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Att lämna denna sida i Redigera läget kan orsaka osparad data. Det är rekommenderat att använda 'Stäng' knappen i stället.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Misslyckades att ladda detta dokument. Försök gärna att öppna det med en extern textredigerare som har stöd för ODT. Detta fel kan bero på att dokumentet nyligen har slutat delas ut eller blivit borttagen.",
    "Save" : "Spara",
    "Loading documents..." : "Laddar dokument...",
    "'.' is an invalid file name." : "'.' är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Ogiltigt namn, '\\', '/', '<', '>', ':', '\"', '|', '?' och '*' är inte tillåtet.",
    "Align Left" : "Vänsterjustera",
    "Alignment" : "Justering",
    "Align Right" : "Högerjustera",
    "Annotate" : "Annotera",
    "Background" : "Bakgrund",
    "Bold" : "Fet",
    "Bottom" : "Botten",
    "Cancel" : "Avbryt",
    "Center" : "Centrerad",
    "Clone" : "Klona",
    "Clone this Style" : "Klona denna stilen",
    "Close" : "Stäng",
    "Color" : "Färg",
    "Create" : "Skapa",
    "Decrease Indent" : "Minska indrag",
    "Default Style" : "Förvald stil",
    "Delete" : "Radera",
    "Family" : "Familj",
    "Font" : "Font",
    "Font Effects" : "Font effekter",
    "Format" : "Format",
    "Increase Indent" : "Öka indrag",
    "Insert Image" : "Infoga bild",
    "Invite Members" : "Bjud in medlemmar",
    "Italic" : "Kursiv",
    "Justified" : "Justerad",
    "Justify" : "Justera",
    "Left" : "Vänster",
    "Loading" : "Laddar",
    "Members" : "Medlemmar",
    "New Name:" : "Nytt namn:",
    "OK" : "OK",
    "Open" : "Öppna",
    "Options" : "Alternativ",
    "Paragraph..." : "Paragraph...",
    "Paragraph Styles" : "Paragrafstilar",
    "Redo" : "Klar",
    "Right" : "Höger",
    "Size" : "Storlek",
    "Spacing" : "Mellanrum",
    "Strikethrough" : "Genomstruket",
    "Style" : "Stil",
    "Text" : "Text",
    "Top" : "Topp",
    "Underline" : "Understrykning",
    "Undo" : "Ångra",
    "Unknown Author" : "Okänd författare",
    "Shared" : "Delad",
    "Error" : "Fel",
    "Error while sharing" : "Fel vid delning",
    "Error while unsharing" : "Fel när delning skulle avslutas",
    "Error while changing permissions" : "Fel vid ändring av rättigheter",
    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delad med dig av {owner}",
    "Share" : "Dela",
    "Share link" : "Dela länk",
    "The public link will expire no later than {days} days after it is created" : "Den publika länken kommer sluta gälla inte senare än {days} dagar efter att den skapades",
    "Link" : "Länk",
    "Password protect" : "Lösenordsskydda",
    "Password" : "Lösenord",
    "Choose a password for the public link" : "Välj ett lösenord för den publika länken",
    "Allow editing" : "Tillåt redigering",
    "Email link to person" : "E-posta länk till person",
    "Send" : "Skicka",
    "Set expiration date" : "Sätt utgångsdatum",
    "Expiration" : "Upphör",
    "Expiration date" : "Utgångsdatum",
    "Adding user..." : "Lägger till användare...",
    "group" : "Grupp",
    "remote" : "fjärr",
    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
    "Shared in {item} with {user}" : "Delad i {item} med {user}",
    "Unshare" : "Sluta dela",
    "notify by email" : "informera via e-post",
    "can share" : "får dela",
    "can edit" : "kan redigera",
    "access control" : "åtkomstkontroll",
    "create" : "skapa",
    "change" : "ändra",
    "delete" : "radera",
    "Password protected" : "Lösenordsskyddad",
    "Error unsetting expiration date" : "Fel vid borttagning av utgångsdatum",
    "Error setting expiration date" : "Fel vid sättning av utgångsdatum",
    "Sending ..." : "Skickar ...",
    "Email sent" : "E-post skickat",
    "Warning" : "Varning",
    "Edit" : "Redigera",
    "guest" : "gäst",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word stöd (kräver OpenOffice/LibreOffice)",
    "Local" : "Lokal",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "OpenOffice/LibreOffice är installerad på denna server. Sökväg till binärmappen är angiven som preview_libreoffice_path i config.php",
    "External" : "Externa",
    "openOffice/libreOffice is installed on external server running a format filter server" : "OpenOffice/LibreOffice är installerad på en extern server som kör en formatfilter-server",
    "Disabled" : "Inaktiverad",
    "No MS Word support" : "Inget MS Word stöd",
    "scheme://domain.tld[:port]" : "ordning://domän.tld[:port]",
    "Server URL" : "Server URL",
    "Apply and test" : "Spara och utför test",
    "New document" : "Nytt dokument",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "Upload" : "Ladda upp",
    "Save new documents to" : "Spara nya dokument till",
    "Wrong password. Please retry." : "Fel lösenord. Försök igen.",
    "Guest %s" : "Gäst %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Länken har löpt ut eller aldrig existerat. Kontakta personen som delade den med dig för ytterligare detaljer.",
    "Advanced feature-set" : "Avancerade inställningar",
    "(Unstable)" : "(Ej stabil)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sv.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokument",
    "Can't create document" : "Kan inte skapa dokument",
    "You don't have permission to rename this document" : "Du har inte behörighet att döpa om detta dokument",
    "Directory saved successfully." : "Katalog sparades.",
    "An error occurred while changing directory." : "Ett fel uppstod vid byte av katalog",
    "Saved" : "Sparad",
    "Format filter server is down or misconfigured" : "Formatfilter servern är ur funktion eller felkonfigurerad",
    "Conversion failed. Check log for details." : "Konvertering misslyckades. Se loggen för detaljer.",
    "Saving..." : "Sparar...",
    "Failed to load documents." : "Kunde inte ladda dokumenten.",
    "No documents were found. Upload or create a document to get started!" : "Inga dokument hittades. Ladda upp eller skapa ett dokument för att komma igång!",
    "No connection to server. Trying to reconnect." : "Ingen kontakt med servern. Försöker att koppla upp igen.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Att lämna denna sida i Redigera läget kan orsaka osparad data. Det är rekommenderat att använda 'Stäng' knappen i stället.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Misslyckades att ladda detta dokument. Försök gärna att öppna det med en extern textredigerare som har stöd för ODT. Detta fel kan bero på att dokumentet nyligen har slutat delas ut eller blivit borttagen.",
    "Save" : "Spara",
    "Loading documents..." : "Laddar dokument...",
    "'.' is an invalid file name." : "'.' är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Ogiltigt namn, '\\', '/', '<', '>', ':', '\"', '|', '?' och '*' är inte tillåtet.",
    "Align Left" : "Vänsterjustera",
    "Alignment" : "Justering",
    "Align Right" : "Högerjustera",
    "Annotate" : "Annotera",
    "Background" : "Bakgrund",
    "Bold" : "Fet",
    "Bottom" : "Botten",
    "Cancel" : "Avbryt",
    "Center" : "Centrerad",
    "Clone" : "Klona",
    "Clone this Style" : "Klona denna stilen",
    "Close" : "Stäng",
    "Color" : "Färg",
    "Create" : "Skapa",
    "Decrease Indent" : "Minska indrag",
    "Default Style" : "Förvald stil",
    "Delete" : "Radera",
    "Family" : "Familj",
    "Font" : "Font",
    "Font Effects" : "Font effekter",
    "Format" : "Format",
    "Increase Indent" : "Öka indrag",
    "Insert Image" : "Infoga bild",
    "Invite Members" : "Bjud in medlemmar",
    "Italic" : "Kursiv",
    "Justified" : "Justerad",
    "Justify" : "Justera",
    "Left" : "Vänster",
    "Loading" : "Laddar",
    "Members" : "Medlemmar",
    "New Name:" : "Nytt namn:",
    "OK" : "OK",
    "Open" : "Öppna",
    "Options" : "Alternativ",
    "Paragraph..." : "Paragraph...",
    "Paragraph Styles" : "Paragrafstilar",
    "Redo" : "Klar",
    "Right" : "Höger",
    "Size" : "Storlek",
    "Spacing" : "Mellanrum",
    "Strikethrough" : "Genomstruket",
    "Style" : "Stil",
    "Text" : "Text",
    "Top" : "Topp",
    "Underline" : "Understrykning",
    "Undo" : "Ångra",
    "Unknown Author" : "Okänd författare",
    "Shared" : "Delad",
    "Error" : "Fel",
    "Error while sharing" : "Fel vid delning",
    "Error while unsharing" : "Fel när delning skulle avslutas",
    "Error while changing permissions" : "Fel vid ändring av rättigheter",
    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delad med dig av {owner}",
    "Share with users or groups …" : "Dela med användare eller grupper ...",
    "Share with users, groups or remote users …" : "Dela med användare, grupper eller fjärranvändare ...",
    "Share" : "Dela",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dela med folk på andra ownClouds med följande syntax username@example.com/owncloud",
    "Share link" : "Dela länk",
    "The public link will expire no later than {days} days after it is created" : "Den publika länken kommer sluta gälla inte senare än {days} dagar efter att den skapades",
    "Link" : "Länk",
    "Password protect" : "Lösenordsskydda",
    "Password" : "Lösenord",
    "Choose a password for the public link" : "Välj ett lösenord för den publika länken",
    "Allow editing" : "Tillåt redigering",
    "Email link to person" : "E-posta länk till person",
    "Send" : "Skicka",
    "Set expiration date" : "Sätt utgångsdatum",
    "Expiration" : "Upphör",
    "Expiration date" : "Utgångsdatum",
    "An error occured. Please try again" : "Ett fel uppstod. Var god försök igen",
    "Adding user..." : "Lägger till användare...",
    "group" : "Grupp",
    "remote" : "fjärr",
    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
    "Shared in {item} with {user}" : "Delad i {item} med {user}",
    "Unshare" : "Sluta dela",
    "notify by email" : "informera via e-post",
    "can share" : "får dela",
    "can edit" : "kan redigera",
    "access control" : "åtkomstkontroll",
    "create" : "skapa",
    "change" : "ändra",
    "delete" : "radera",
    "Password protected" : "Lösenordsskyddad",
    "Error unsetting expiration date" : "Fel vid borttagning av utgångsdatum",
    "Error setting expiration date" : "Fel vid sättning av utgångsdatum",
    "Sending ..." : "Skickar ...",
    "Email sent" : "E-post skickat",
    "Warning" : "Varning",
    "Edit" : "Redigera",
    "guest" : "gäst",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word stöd (kräver OpenOffice/LibreOffice)",
    "Local" : "Lokal",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "OpenOffice/LibreOffice är installerad på denna server. Sökväg till binärmappen är angiven som preview_libreoffice_path i config.php",
    "External" : "Externa",
    "openOffice/libreOffice is installed on external server running a format filter server" : "OpenOffice/LibreOffice är installerad på en extern server som kör en formatfilter-server",
    "Disabled" : "Inaktiverad",
    "No MS Word support" : "Inget MS Word stöd",
    "scheme://domain.tld[:port]" : "ordning://domän.tld[:port]",
    "Server URL" : "Server URL",
    "Apply and test" : "Spara och utför test",
    "New document" : "Nytt dokument",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "Upload" : "Ladda upp",
    "Save new documents to" : "Spara nya dokument till",
    "Wrong password. Please retry." : "Fel lösenord. Försök igen.",
    "Guest %s" : "Gäst %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Länken har löpt ut eller aldrig existerat. Kontakta personen som delade den med dig för ytterligare detaljer.",
    "Advanced feature-set" : "Avancerade inställningar",
    "(Unstable)" : "(Ej stabil)"
},
"nplurals=2; plural=(n != 1);");
